@@ -10,25 +10,31 @@
 
 #include <wayland-client.h>
 
+#include "qwaylandlayershellintegration_p.h"
+
 #include "layershellqt_export.h"
 #include <QtWaylandClient/private/qwaylandshellsurface_p.h>
 #include <qwayland-wlr-layer-shell-unstable-v1.h>
 
 namespace LayerShellQt
 {
-class QWaylandLayerShell;
+
+class Window;
 
 class LAYERSHELLQT_EXPORT QWaylandLayerSurface : public QtWaylandClient::QWaylandShellSurface, public QtWayland::zwlr_layer_surface_v1
 {
     Q_OBJECT
 public:
-    QWaylandLayerSurface(QWaylandLayerShell *shell, QtWaylandClient::QWaylandWindow *window);
+    QWaylandLayerSurface(QWaylandLayerShellIntegration *shell, QtWaylandClient::QWaylandWindow *window);
     ~QWaylandLayerSurface() override;
 
     bool isExposed() const override
     {
         return m_configured;
     }
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+    void attachPopup(QtWaylandClient::QWaylandShellSurface *popup) override;
+#endif
 
     void setAnchor(uint32_t anchor);
     void setExclusiveZone(int32_t zone);
@@ -37,12 +43,20 @@ public:
     void setLayer(uint32_t layer);
 
     void applyConfigure() override;
+    void setWindowGeometry(const QRect &geometry) override;
+
+    bool requestActivate() override;
+    void setXdgActivationToken(const QString &token) override;
+    void requestXdgActivationToken(quint32 serial) override;
 
 private:
     void zwlr_layer_surface_v1_configure(uint32_t serial, uint32_t width, uint32_t height) override;
     void zwlr_layer_surface_v1_closed() override;
 
+    QWaylandLayerShellIntegration *m_shell;
+    LayerShellQt::Window *m_interface;
     QSize m_pendingSize;
+    QString m_activationToken;
     bool m_configured = false;
 };
 
